component

Attribute Macro component 

#[component]
The component attribute macro for marking component functions.

This is a pass-through attribute macro that does not modify the item. It serves as a marker to indicate that the annotated function is a UI component that returns a VirtualNode.

Arguments

  • TokenStream - The attribute arguments (unused).
  • TokenStream - The item being annotated (passed through unchanged).

Returns

  • TokenStream - The original item unchanged.